@@ -9,9 +9,7 @@
 // @param give_log bool. Return log of density
 template<class Type> 
 Type skew_norm(Type x, Type alpha, Type omega, Type xi, bool give_log){
-  
   Type dens = log(Type(2)) + dnorm(x, xi, omega, true) + log(Type(0.00001) + pnorm(alpha * (x - xi) / omega));
-  
   if(give_log) return dens;
   else return exp(dens);
   
@@ -35,7 +33,6 @@ Type objective_function<Type>::operator()(){
   DATA_INTEGER(model);
   DATA_VECTOR_INDICATOR(keep, y);  // For one-step predictions
   
-  
   // Parameters-----------------
   PARAMETER(log_sigma_y); 
   PARAMETER(log_sigma_h);
@@ -50,7 +47,6 @@ Type objective_function<Type>::operator()(){
   Type sigma_h = exp(log_sigma_h); 
   Type phi = f(logit_phi); 
   
-
   ADREPORT(sigma_y); 
   ADREPORT(sigma_h); 
   ADREPORT(phi); 
@@ -64,9 +60,7 @@ Type objective_function<Type>::operator()(){
   nll -= dnorm(h(0), Type(0), sigma_h / sqrt(1 - phi * phi), true); 
   
   for(int i = 1; i < N; i++){
-    
     nll -= dnorm(h(i), phi * h(i - 1), sigma_h, true); 
-    
   }
   
   // Contribution from observations
@@ -92,40 +86,34 @@ Type objective_function<Type>::operator()(){
     
     // Skew normal distribution
     case 2:{
-      
       Type scale = sigma_y * exp(h(i) / Type(2));
       Type delta = alpha(0) / sqrt(1 + alpha(0) * alpha(0)); 
       Type omega = scale / sqrt(Type(1) - Type(2) * delta * delta / M_PI); 
       Type xi = - omega * delta * sqrt(Type(2) / M_PI);
-      
       nll -= keep(i) * skew_norm(y(i), alpha(0), omega, xi, true);
       break;
       }
     
     // Leverage model - normal distribution
     case 3:{
-      
       Type rho = f(logit_rho(0));
       if(i == 0){
-      ADREPORT(rho); // only report once
+        ADREPORT(rho); // only report once
       }
       if(i < (N - 1)){
-
         Type eta = (h(i + 1) - phi * h(i)) / sigma_h; 
         nll -= keep(i) * dnorm(y(i), sigma_y * exp(h(i) / Type(2)) * rho * eta, sigma_y * exp(h(i) / Type(2)) * sqrt(Type(1) - rho * rho), true); 
-        
       }
       break;
     }
       
-  
     // TODO: 
     // Skew t distribution
     // Skew gaussian with leverage
     // Skew t with leverage
     
     default:
-      error("This distribution is not implementet!");
+      Rf_error("This distribution is not implementet!");
       break;
     }
   }
